# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"view": "utils.ipynb",
         "bytes_encode": "utils.ipynb",
         "bytes_decode": "utils.ipynb",
         "timer_start": "utils.ipynb",
         "timer_end": "utils.ipynb",
         "to_bytesio": "utils.ipynb",
         "cprint": "utils.ipynb",
         "arr2im": "vision.ipynb",
         "im2bytes": "vision.ipynb",
         "check_im": "vision.ipynb",
         "open_im": "vision.ipynb"}

modules = ["utils.py",
           "vision/core.py"]

doc_url = "https://pattyhendrix.github.io/badai/"

git_url = "https://github.com/pattyhendrix/badai/tree/master/"

def custom_doc_links(name): return None
